"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LabelService = void 0;
const graphql_request_1 = require("graphql-request");
const constellation_sxa_nextjs_1 = require("@constellation4sitecore/constellation-sxa-nextjs");
const foundation_mapper_1 = require("@constellation4sitecore/foundation-mapper");
class LabelService {
    /**
     *
     */
    constructor(language) {
        this.language = language ? language : constellation_sxa_nextjs_1.config.defaultLanguage;
    }
    getLabelsForView(labelId) {
        return __awaiter(this, void 0, void 0, function* () {
            const graphqlFactory = (0, constellation_sxa_nextjs_1.createGraphQLClientFactory)();
            const graphQLClient = graphqlFactory({
                debugger: constellation_sxa_nextjs_1.debug.labels,
            });
            const query = (0, graphql_request_1.gql) `
      query GetLabels($labelId: String!, $language: String!) {
        labels: item(path: $labelId, language: $language) {
          id
          fields {
            name
            value
            jsonValue
          }
        }
      }
    `;
            const result = yield graphQLClient.request(query, {
                labelId: labelId,
                language: this.language,
            });
            if (!result.labels) {
                constellation_sxa_nextjs_1.debug.labels(`No labels found for labelId: ${labelId}. Do you forget to publish?`);
                return null;
            }
            const label = (0, foundation_mapper_1.mapToNew)(result.labels);
            return label;
        });
    }
}
exports.LabelService = LabelService;
