var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { gql } from 'graphql-request';
import { createGraphQLClientFactory, debug as debuggers, config, } from '@constellation4sitecore/constellation-sxa-nextjs';
import { mapToNew } from '@constellation4sitecore/foundation-mapper';
export class LabelService {
    /**
     *
     */
    constructor(language) {
        this.language = language ? language : config.defaultLanguage;
    }
    getLabelsForView(labelId) {
        return __awaiter(this, void 0, void 0, function* () {
            const graphqlFactory = createGraphQLClientFactory();
            const graphQLClient = graphqlFactory({
                debugger: debuggers.labels,
            });
            const query = gql `
      query GetLabels($labelId: String!, $language: String!) {
        labels: item(path: $labelId, language: $language) {
          id
          fields {
            name
            value
            jsonValue
          }
        }
      }
    `;
            const result = yield graphQLClient.request(query, {
                labelId: labelId,
                language: this.language,
            });
            if (!result.labels) {
                debuggers.labels(`No labels found for labelId: ${labelId}. Do you forget to publish?`);
                return null;
            }
            const label = mapToNew(result.labels);
            return label;
        });
    }
}
